# -*- coding: utf-8 -*-
import socket
from time import time


class Galena(object):
    def __init__(self, host="localhost", port=2003):
        self._addr = (host, port)
        self._sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self._sock.connect(self._addr)

    def send(self, metric, value, timestamp=None):
        try:
            self._sock.send("%s %g %s\n\n" % (metric, value,
                timestamp or int(time())))
        except socket.error:
            pass  # Failing silently for now



# -*- coding: utf-8 -*-
try:
    from django.conf import settings
except ImportError:
    settings = None

from client import Galena

__all__ = ['Galena', 'galena']

if settings:
    try:
        host = getattr(settings, 'GRAPHITE_HOST', 'localhost')
        port = getattr(settings, 'GRAPHITE_PORT', 2003)
        galena = Galena(host, port)
    except ImportError:
        galena = None



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages


setup(
    name='galena',
    version='0.3',
    description='Dumb but useful graphite/carbon client.',
    author='Timothée Peignier',
    author_email='tpeignier@20minutes.fr',
    url='https://github.com/20minutes/galena',
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    test_suite='galena.tests',
    tests_require=['mock'],
    classifiers=[
        'Intended Audience :: System Administrators',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities',
    ]
)



# -*- coding: utf-8 -*-
import unittest
from mock import patch, Mock

from galena import Galena


class TestGalena(unittest.TestCase):
    @patch('socket.socket')
    def test_send_metric(self, mock):
        socket = Mock()
        mock.return_value = socket
        galena = Galena()
        galena.send("tiger.flu", 1, 1311003170)
        self.assertTrue(mock.called)
        self.assertEquals(socket.method_calls[0], (
            'connect', (('localhost', 2003),), {}
        ))
        self.assertEquals(socket.method_calls[1], (
            'send', ('tiger.flu 1 1311003170',), {}
        ))

if __name__ == '__main__':
    unittest.main()
